@@ -217,7 +217,7 @@ class WBPaper(object):
             file_paths = self.db_manager.get_file_paths(self.paper_id)
             for file_path in file_paths:
                 filename = file_path.split("/")[-1]
-                if filename.lower().endswith(".pdf"):
+                if filename.lower().endswith(".pdf") or re.match(r'^[0-9]+$', filename):
                     dir_path = file_path.rstrip(filename)
                     self.add_file(dir_path=dir_path, filename=filename, remote_file=True, pdf=True)
         else:
